Asyncio Python Client for Google Cloud Storage
==============================================

|aio-pypi| |aio-pythons| |rest-pypi| |rest-pythons|

Installation
------------

.. code-block:: console

    $ pip install --upgrade gcloud-rest-storage
    # or
    $ pip install --upgrade gcloud-rest-storage

Usage
-----

We're still working on documentation -- for now, you can use the `smoke test`_
as an example.

Contributing
------------

Please see our `contributing guide`_.

.. _contributing guide: https://github.com/talkiq/gcloud-rest/blob/master/.github/CONTRIBUTING.rst
.. _smoke test: https://github.com/talkiq/gcloud-rest/blob/master/storage/tests/integration/smoke_test.py

.. |aio-pypi| image:: https://img.shields.io/pypi/v/gcloud-rest-storage.svg?style=flat-square&label=pypi (aio)
    :alt: Latest PyPI Version (gcloud-rest-storage)
    :target: https://pypi.org/project/gcloud-rest-storage/

.. |aio-pythons| image:: https://img.shields.io/pypi/pyversions/gcloud-rest-storage.svg?style=flat-square&label=python (aio)
    :alt: Python Version Support (gcloud-rest-storage)
    :target: https://pypi.org/project/gcloud-rest-storage/

.. |rest-pypi| image:: https://img.shields.io/pypi/v/gcloud-rest-storage.svg?style=flat-square&label=pypi (rest)
    :alt: Latest PyPI Version (gcloud-rest-storage)
    :target: https://pypi.org/project/gcloud-rest-storage/

.. |rest-pythons| image:: https://img.shields.io/pypi/pyversions/gcloud-rest-storage.svg?style=flat-square&label=python (rest)
    :alt: Python Version Support (gcloud-rest-storage)
    :target: https://pypi.org/project/gcloud-rest-storage/
